import{_ as u}from"./index-DszNaKSN.js";import{u as f}from"./vue-router-DHBbBOYe.js";import{f as b,g as k}from"./vuetify-Cc3ogKHH.js";import{d as $,G as y,H as l,J as a,e as s,c,O as p,n as m,F as _,a4 as i,u as o,a2 as v,aF as h,aW as F,b as r}from"./lucide-OrjrigGq.js";import{_ as N}from"./index-STpfFCKU.js";import"./reka-ui-DIvBdk1-.js";import"./vueuse-BZBkof_U.js";import"./index-DIT3TkWC.js";import"./qrcode-BWzeHGfy.js";import"./marked-BPdRUrA1.js";import"./vue-i18n-B2QXlTQD.js";import"./color-CqFg8eif.js";/* empty css            */import"./swiper-Bq331F5K.js";const z={class:"not-found"},C={class:"content"},V={class:"vinyl-scene"},g={class:"vinyl"},x={class:"headline"},B={class:"subtext"},A={class:"equalizer","aria-hidden":"true"},q={class:"actions"},w=$({name:"NotFound",__name:"NotFound",setup(L){const d=f();return(n,e)=>(r(),y(b,null,{default:l(()=>[a(k,null,{default:l(()=>[s("div",z,[s("div",C,[s("div",V,[s("div",g,[(r(),c(_,null,p(6,t=>s("div",{key:t,class:"groove",style:m(`--i: ${t}`)},null,4)),64)),e[2]||(e[2]=s("div",{class:"label"},[s("div",{class:"label-text"},"MA"),s("div",{class:"label-hole"})],-1))]),e[3]||(e[3]=s("div",{class:"needle-arm"},[s("div",{class:"needle-rod"}),s("div",{class:"needle-head"})],-1))]),e[4]||(e[4]=s("h1",{class:"error-code"},[s("span",null,"4"),s("span",{class:"zero"},"0"),s("span",null,"4")],-1)),s("p",x,i(n.$t("not_found_headline")),1),s("p",B,i(n.$t("not_found_subtext")),1),s("div",A,[(r(),c(_,null,p(12,t=>s("div",{key:t,class:"eq-bar",style:m(`--i: ${t}`)},null,4)),64))]),s("div",q,[a(o(u),{variant:"default",onClick:e[0]||(e[0]=t=>o(d).back())},{default:l(()=>[a(o(h),{class:"size-4"}),v(" "+i(n.$t("back")),1)]),_:1}),a(o(u),{variant:"outline",onClick:e[1]||(e[1]=t=>o(d).push("/discover"))},{default:l(()=>[a(o(F),{class:"size-4"}),v(" "+i(n.$t("discover")),1)]),_:1})])])])]),_:1})]),_:1}))}}),P=N(w,[["__scopeId","data-v-40deed24"]]);export{P as default};
