import{e as a}from"./index-STpfFCKU.js";import{d as r,c as o,ae as n,u as l,h as c,b as p}from"./lucide-OrjrigGq.js";const u=r({__name:"CardDescription",props:{class:{type:[Boolean,null,String,Object,Array]}},setup(s){const e=s;return(t,d)=>(p(),o("p",{"data-slot":"card-description",class:n(l(a)("text-muted-foreground text-sm",e.class))},[c(t.$slots,"default")],2))}}),_=r({__name:"CardTitle",props:{class:{type:[Boolean,null,String,Object,Array]}},setup(s){const e=s;return(t,d)=>(p(),o("h3",{"data-slot":"card-title",class:n(l(a)("leading-none font-semibold",e.class))},[c(t.$slots,"default")],2))}});export{_,u as a};
